#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-client
version:              0.0.4
visibility:           public
id:                   casa-client-0.0.4-15okJi1E45rEesUIcufxwN
key:                  casa-client-0.0.4-15okJi1E45rEesUIcufxwN
license:              BSD-3-Clause
copyright:
    2018-2019 FP Complete,
    2024-2025 Haskell Foundation

maintainer:
    Chris Done <chrisdone@fpcomplete.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Chris Done
homepage:             https://github.com/commercialhaskell/casa#readme
synopsis:             Client for Casa
description:
    Client for Casa (Content-Addressable Storage Archive). See
    <https://casa.stackage.org/>

category:             Development
abi:                  88278c1552c88acf52e2c40ee8eb0dda
exposed:              True
exposed-modules:      Casa.Client
import-dirs:          /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-client
hs-libraries:         HScasa-client-0.0.4-15okJi1E45rEesUIcufxwN
depends:
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN
    attoparsec-0.14.4-DVQW3zaPrEjFLUvmkAZYCq base-4.18.2.1
    base16-bytestring-1.0.2.0-HKNPUjeO8LQ9RSeGAokMwf
    bytestring-0.11.5.3 casa-types-0.0.3-5LIKh1e5dM8GXuqT3aWZjs
    conduit-1.3.6.1-BJxsltXT31mLaWStW2N7GT
    conduit-extra-1.3.8-IyKWOH8Hunx4h59nOk18Zo
    cryptohash-sha256-0.11.102.1-4R9GlEZ6qHp5oHAfvlM0Nv
    exceptions-0.10.7 http-conduit-2.3.9.1-FrAJpmFGoH8LJwYwHDjzEb
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    network-uri-2.6.4.2-HyBVnFdXLs0Dgiq4qkHmFH
    resourcet-1.3.0-1zDmXgfXfhGHcZ53EkSGgY template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

